@@ -49,7 +49,7 @@ class SharedThrough(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -73,7 +73,7 @@ class SharedThrough(object):
 		The method to get the entity_name
 
 		Returns:
-			string: A string value
+			string: A string representing the entity_name
 		"""
 
 		return self.__entity_name
@@ -100,7 +100,7 @@ class SharedThrough(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
