@@ -24,7 +24,7 @@ class TerritoriesOperations(object):
 
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/territories'
+		api_path = api_path + '/crm/v2.1/settings/territories'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -53,7 +53,7 @@ class TerritoriesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/territories/'
+		api_path = api_path + '/crm/v2.1/settings/territories/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
