@@ -6,8 +6,7 @@ class Choice(object):
     """
 
     def __init__(self, value):
-        self.value = value
+        self.__value = value
 
     def get_value(self):
-        return self.value
-
+        return self.__value
