@@ -53,7 +53,8 @@ class JSONConverter(Converter):
                 request_class_path_lower = request_object_class_name.lower()
                 if class_name_interface_lower == request_class_path_lower:
                     class_detail = dict(Initializer.json_details[str(class_name)])
-
+                    class_name = str(class_name).rpartition(".")
+                    class_name = self.module_to_class(class_name[-1])
                     break
 
         try:
@@ -696,19 +697,6 @@ class JSONConverter(Converter):
 
         return class_holder()
 
-    @staticmethod
-    def module_to_class(module_name):
-        class_name = module_name
-
-        if "_" in module_name:
-            class_name = ''
-            module_split = str(module_name).split('_')
-
-            for each_name in module_split:
-                each_name = each_name.capitalize()
-                class_name += each_name
-
-        return class_name
 
     @staticmethod
     def construct_private_member(class_name, member_name):
